@@ -26,7 +26,9 @@
 #include <d3dcommon.h>
 #include <algorithm>
 #include <array>
+#ifdef BIT_CAST_SUPPORTED
 #include <bit>
+#endif
 #include <cassert>
 #include <errno.h>
 #include <exception>
@@ -41,7 +43,9 @@
 #include <filesystem>
 #include <iostream>
 #include <memory>
+#ifdef RANGES_SUPPORTED
 #include <ranges>
+#endif
 #include <stdlib.h>
 #include <string>
 #include <string.h>
@@ -56,11 +60,8 @@
 #endif
 
 #ifdef USE_FMT_LIBRARY
-#ifdef _MSC_VER
-#pragma comment(lib, "fmtd.lib")
-#endif
-#if defined(__BORLANDC__)
-#pragma comment(lib, "fmtd.lib")
+#if ( _MSC_VER )
+#pragma comment(lib, "fmt")
 #endif
 #endif
 
