@@ -77,6 +77,7 @@ namespace efxc2Cmds {
 	constexpr const wchar_t* M_DEBUG = L"debug";
 	constexpr const wchar_t* M_DECOMPRESS = L"decompress";
 	constexpr const wchar_t* M_DUMPBIN = L"dumpbin";
+	/*This has to be M_E_ instead of M_E as that conflicts with a constant in math.h*/
 	constexpr const wchar_t* M_E_ = L"E";
 	constexpr const wchar_t* M_ENABLE_UNBOUNDED_DESCRIPTOR_TABLES = L"enable_unbounded_descriptor_tables";
 	constexpr const wchar_t* M_FC = L"Fc";
@@ -191,6 +192,35 @@ namespace efxc2Cmds {
 	constexpr const char* M_ZSS = "Zss";
 #endif /* _WIN32 */
 
+	/*flag var names*/
+constexpr auto M_SFLAGS_VAR = "sflags";
+constexpr auto M_EFLAGS_VAR = "eflags";
+constexpr auto M_STRIP_FLAGS_VAR = "strip_flags";
+constexpr auto M_DISASM_FLAGS_VAR = "disassembly_flags";
+
+	/*Parameter Descriptions*/
+#ifdef _WIN32
+constexpr auto M_E_DESCR = L"Entry Point";
+constexpr auto M_FC_DESCR = L"Assembly Code";
+constexpr auto M_FD_DESCR = L".PDB";
+constexpr auto M_FH_DESCR = L"Header File";
+constexpr auto M_FO_DESCR = L"Object File";
+constexpr auto M_I_DESCR = L"Include Dir";
+constexpr auto M_P_DESCR = L"Preprocessed Output";
+constexpr auto M_SETPRIVATE_DESCR = L"Private Data";
+constexpr auto M_T_DESCR = L"Shader Model/Profile";
+#else
+constexpr auto M_E_DESCR = "Entry Point";
+constexpr auto M_FC_DESCR = "Assembly Code";
+constexpr auto M_FD_DESCR = ".PDB";
+constexpr auto M_FH_DESCR = "Header File";
+constexpr auto M_FO_DESCR = "Object File";
+constexpr auto M_I_DESCR = "Include Dir";
+constexpr auto M_P_DESCR = "Preprocessor Output";
+constexpr auto M_SETPRIVATE_DESCR = "Private Data";
+constexpr auto M_T_DESCR = "Shader Model/Profile";
+#endif
+
 	using gCompilerFilep = void(efxc2CompilerParams::CompilerParams&, efxc2Files::Files&, const efxc2Utils::M_STRING_VIEW);
 	struct CompileFileEntry {
 		const efxc2Utils::M_STRING Param;
@@ -214,6 +244,17 @@ namespace efxc2Cmds {
 		efxc2CompilerParams::CompilerParams& params,
 		efxc2Files::Files& files);
 
+	void print_flag_parameter(_In_ const efxc2CompilerParams::CompilerParams& ComParams,
+		_In_ const std::string_view cmdParam,
+		_In_ const std::string_view AFlagsVar,
+		_In_ const std::string_view AflagName);
+
+	void print_string_parameter(_In_ const efxc2CompilerParams::CompilerParams& ComParams,
+		_In_ const efxc2Utils::M_STRING_VIEW cmdParam,
+		_In_ const efxc2Utils::M_STRING_VIEW ADesc,
+		_In_ const efxc2Utils::M_STRING_VIEW fileName);
+
+
 	using gCompilerp = void(efxc2CompilerParams::CompilerParams&);
 	struct CompilerOnlyEntry {
 		const efxc2Utils::M_STRING Param;
