@@ -9,6 +9,9 @@
 //--------------------------------------------------------------------------------------
 
 #pragma once
+
+#ifndef EFXC2EXCEPTION_H_INCLUDED
+#define EFXC2EXCEPTION_H_INCLUDED
 #include "efxc2.h"
 
 namespace efxc2Exception {
@@ -27,4 +30,5 @@ namespace efxc2Exception {
 	class NoInputFile : public ProgramExceptionBase {};
 	class CompileError : public ProgramExceptionBase {};
 	class PreprocessError : public ProgramExceptionBase {};
-}
\ No newline at end of file
+}
+#endif
